Payment receipt

#### Receipt: 00035 - Value: $100.00 - Date: 01/01/12

Drawee |
I/We Received from: | Stoq Roupas e Acessórios Ltda
Address: | Avendia São Carlos 2333, Centro
The importance of: | ONE HUNDRED REAIS
Referring to: | Test payable account
Recipient |
Recipient: | Supplier
RG/CPF/CNPJ: | 90.117.749/7654-80
Address: | Mainstreet 138, Cidade Araci

Recipient

#### Receipt: 00035 - Value: $100.00 - Date: 01/01/12

Drawee |
I/We Received from: | Stoq Roupas e Acessórios Ltda
Address: | Avendia São Carlos 2333, Centro
The importance of: | ONE HUNDRED REAIS
Referring to: | Test payable account
Recipient |
Recipient: | Supplier
RG/CPF/CNPJ: | 90.117.749/7654-80
Address: | Mainstreet 138, Cidade Araci

Recipient